import java.util.*;
import javax.swing.*;
import java.awt.*;
import java.awt.image.*;
import java.awt.event.*;
import java.awt.geom.*;

class CompositingAlpha2Frame extends JFrame {

    private DrawPanel drawPanel = new DrawPanel();
    private JComboBox options;
	private BufferedImage source, dest;
    
    class DrawPanel extends JPanel {
   
      public DrawPanel() {
        setBackground(Color.lightGray);
      }
      
      public Dimension getPreferredSize() {
        return new Dimension(200, 150);
      }
    
      public void paintComponent(Graphics g) {
        super.paintComponent(g);
        Graphics2D g2 = (Graphics2D) g;

        // Create off-screen image for destination
        dest = new BufferedImage(200, 150, BufferedImage.TYPE_INT_ARGB);
        Graphics2D  destG = dest.createGraphics();
        
        // Paint destination element (red ellipse)   
        destG.setPaint(Color.red);
        destG.fill(new Ellipse2D.Double(20, 50, 150, 50));
        
        // Create off-screen image for source
        source = new BufferedImage(200, 150, BufferedImage.TYPE_INT_ARGB);
        Graphics2D  sourceG = source.createGraphics();
        
        // Paint source element (blue rectangle)
        sourceG.setPaint(Color.blue);
        sourceG.fill(new Rectangle2D.Double(75, 20, 50, 110));

        // Obtain compositing rule from user
        String rule = (String)options.getSelectedItem();
        int ruleCode = AlphaComposite.SRC_OVER;
        if (rule.equals("Src")) ruleCode = AlphaComposite.SRC;
        if (rule.equals("Dst")) ruleCode = AlphaComposite.DST;
        if (rule.equals("Src-Over-Dst")) ruleCode = AlphaComposite.SRC_OVER;
        if (rule.equals("Dst-Over-Src")) ruleCode = AlphaComposite.DST_OVER;
        if (rule.equals("Src-In-Dst")) ruleCode = AlphaComposite.SRC_IN;
        if (rule.equals("Dst-In-Src")) ruleCode = AlphaComposite.DST_IN;
        if (rule.equals("Src-Out-Dst")) ruleCode = AlphaComposite.SRC_OUT;
        if (rule.equals("Dst-Out-Src")) ruleCode = AlphaComposite.DST_OUT;
        if (rule.equals("Src-Atop-Dst")) ruleCode = AlphaComposite.SRC_ATOP;
        if (rule.equals("Dst-Atop-Src")) ruleCode = AlphaComposite.DST_ATOP;
        if (rule.equals("Clear")) ruleCode = AlphaComposite.CLEAR;
        if (rule.equals("Xor")) ruleCode = AlphaComposite.XOR;
        
        //Compose source with destination, within destG
        destG.setComposite(AlphaComposite.getInstance(ruleCode, 0.6f));
        destG.drawImage(source, 0, 0, null);
        
        // Display on screen
        g2.drawImage(dest, 0, 0, null);
      }
    }

	public CompositingAlpha2Frame() {
	 	setTitle("AlphaCompositing");
	 	getContentPane().add(drawPanel,BorderLayout.NORTH);
	 	JPanel controlPanel = new JPanel();
	 	getContentPane().add(controlPanel,BorderLayout.SOUTH);
	 	
        options = new JComboBox(
          new String[] {"Src", "Dst", "Src-Over-Dst", "Dst-Over-Src", "Src-In-Dst", "Dst-In-Src", "Src-Out-Dst", 
            "Dst-Out-Src", "Src-Atop-Dst", "Dst-Atop-Src", "Clear", "Xor"});
        options.addItemListener(new ItemListener() {
          public void itemStateChanged(ItemEvent ie) {
            repaint();
          }
        });
        controlPanel.add(options);
	 	
        JButton exitButton = new JButton("Exit");
	 	exitButton.addActionListener(new ActionListener(){
	 	  public void actionPerformed (ActionEvent event) {
            System.exit(0);
          }
	 	});
	 	controlPanel.add(exitButton);
	 	
	 	addWindowListener(new WindowAdapter(){
	 	  public void windowClosing(WindowEvent we) {
            System.exit(0);
          }
         });
	 	
	 	pack();
	 	setVisible(true);
	 }
	 
}

class CompositingAlpha2 {

  public static void main (String[] argv) {	
    CompositingAlpha2Frame cf = new CompositingAlpha2Frame();
  }
}
